# sensAI-Utils

This project provides the `util` package from sensAI, the Python library for sensible AI,
allowing it to be used without the additional dependencies of sensAI.

## Contributing

Contributions should be made directly in [sensAI](.github/workflows/test.yaml).